.. warning::
    Legacy client is obsolete, please use Client version 3 instead. :ref:`This document <migration>` describes the migration process.


Responses
=========

.. autoclass:: copr.client.responses.CoprResponse
    :members:

.. autoclass:: copr.client.responses.BaseHandle
    :members:

.. autoclass:: copr.client.responses.ProjectHandle
    :members:

.. autoclass:: copr.client.responses.BuildHandle
    :members:

.. autoclass:: copr.client.responses.ProjectChrootHandle
    :members:


Data wrappers
=============

.. autoclass:: copr.client.responses.ProjectWrapper
    :members:

.. autoclass:: copr.client.responses.BuildWrapper
    :members:

.. autoclass:: copr.client.responses.ProjectChrootWrapper
    :members:
